==========
clientxmpp
==========

.. module:: sleekxmpp.clientxmpp

.. autoclass:: ClientXMPP
    
    .. automethod:: connect

    .. automethod:: register_feature

    .. automethod:: get_roster

    .. automethod:: update_roster

    .. automethod:: del_roster_item
